# cbook

## Overview

This is an app to manage recipes.

Features:
* Create, edit, delete recipes
* Change servings of a recipe on the recipe view page
* Filter for tags in the recipe list

__Text in this app is only in german for now! 
Other language support shall be implemented in the future (at least English)!__

## Dependencies

This app (and it's installation) depends on:
* python
* pip

## Installation

This app is hosted on PyPI so it can be installed using `pip`:

```
$ python -m pip install cbook
```
